﻿/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Polish language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Zwiń pasek narzędzi",
ToolbarExpand		: "Rozwiń pasek narzędzi",

// Toolbar Items and Context Menu
Save				: "Zapisz",
NewPage				: "Nowa strona",
Preview				: "Podgląd",
Cut					: "Wytnij",
Copy				: "Kopiuj",
Paste				: "Wklej",
PasteText			: "Wklej jako czysty tekst",
PasteWord			: "Wklej z Worda",
Print				: "Drukuj",
SelectAll			: "Zaznacz wszystko",
RemoveFormat		: "Usuń formatowanie",
InsertLinkLbl		: "Hiperłącze",
InsertLink			: "Wstaw/edytuj hiperłącze",
RemoveLink			: "Usuń hiperłącze",
VisitLink			: "Open Link",	//MISSING
Anchor				: "Wstaw/edytuj kotwicę",
AnchorDelete		: "Usuń kotwicę",
InsertImageLbl		: "Obrazek",
InsertImage			: "Wstaw/edytuj obrazek",
InsertFlashLbl		: "Flash",
InsertFlash			: "Dodaj/Edytuj element Flash",
InsertTableLbl		: "Tabela",
InsertTable			: "Wstaw/edytuj tabelę",
InsertLineLbl		: "Linia pozioma",
InsertLine			: "Wstaw poziomą linię",
InsertSpecialCharLbl: "Znak specjalny",
InsertSpecialChar	: "Wstaw znak specjalny",
InsertSmileyLbl		: "Emotikona",
InsertSmiley		: "Wstaw emotikonę",
About				: "O programie FCKeditor",
Bold				: "Pogrubienie",
Italic				: "Kursywa",
Underline			: "Podkreślenie",
StrikeThrough		: "Przekreślenie",
Subscript			: "Indeks dolny",
Superscript			: "Indeks górny",
LeftJustify			: "Wyrównaj do lewej",
CenterJustify		: "Wyrównaj do środka",
RightJustify		: "Wyrównaj do prawej",
BlockJustify		: "Wyrównaj do lewej i prawej",
DecreaseIndent		: "Zmniejsz wcięcie",
IncreaseIndent		: "Zwiększ wcięcie",
Blockquote			: "Cytat",
CreateDiv			: "Create Div Container",	//MISSING
EditDiv				: "Edit Div Container",	//MISSING
DeleteDiv			: "Remove Div Container",	//MISSING
Undo				: "Cofnij",
Redo				: "Ponów",
NumberedListLbl		: "Lista numerowana",
NumberedList		: "Wstaw/usuń numerowanie listy",
BulletedListLbl		: "Lista wypunktowana",
BulletedList		: "Wstaw/usuń wypunktowanie listy",
ShowTableBorders	: "Pokazuj ramkę tabeli",
ShowDetails			: "Pokaż szczegóły",
Style				: "Styl",
FontFormat			: "Format",
Font				: "Czcionka",
FontSize			: "Rozmiar",
TextColor			: "Kolor tekstu",
BGColor				: "Kolor tła",
Source				: "Źródło dokumentu",
Find				: "Znajdź",
Replace				: "Zamień",
SpellCheck			: "Sprawdź pisownię",
UniversalKeyboard	: "Klawiatura Uniwersalna",
PageBreakLbl		: "Odstęp",
PageBreak			: "Wstaw odstęp",

Form			: "Formularz",
Checkbox		: "Pole wyboru (checkbox)",
RadioButton		: "Pole wyboru (radio)",
TextField		: "Pole tekstowe",
Textarea		: "Obszar tekstowy",
HiddenField		: "Pole ukryte",
Button			: "Przycisk",
SelectionField	: "Lista wyboru",
ImageButton		: "Przycisk-obrazek",

FitWindow		: "Maksymalizuj rozmiar edytora",
ShowBlocks		: "Pokaż bloki",

// Context Menu
EditLink			: "Edytuj hiperłącze",
CellCM				: "Komórka",
RowCM				: "Wiersz",
ColumnCM			: "Kolumna",
InsertRowAfter		: "Wstaw wiersz poniżej",
InsertRowBefore		: "Wstaw wiersz powyżej",
DeleteRows			: "Usuń wiersze",
InsertColumnAfter	: "Wstaw kolumnę z prawej",
InsertColumnBefore	: "Wstaw kolumnę z lewej",
DeleteColumns		: "Usuń kolumny",
InsertCellAfter		: "Wstaw komórkę z prawej",
InsertCellBefore	: "Wstaw komórkę z lewej",
DeleteCells			: "Usuń komórki",
MergeCells			: "Połącz komórki",
MergeRight			: "Połącz z komórką z prawej",
MergeDown			: "Połącz z komórką poniżej",
HorizontalSplitCell	: "Podziel komórkę poziomo",
VerticalSplitCell	: "Podziel komórkę pionowo",
TableDelete			: "Usuń tabelę",
CellProperties		: "Właściwości komórki",
TableProperties		: "Właściwości tabeli",
ImageProperties		: "Właściwości obrazka",
FlashProperties		: "Właściwości elementu Flash",

AnchorProp			: "Właściwości kotwicy",
ButtonProp			: "Właściwości przycisku",
CheckboxProp		: "Właściwości pola wyboru (checkbox)",
HiddenFieldProp		: "Właściwości pola ukrytego",
RadioButtonProp		: "Właściwości pola wyboru (radio)",
ImageButtonProp		: "Właściwości przycisku obrazka",
TextFieldProp		: "Właściwości pola tekstowego",
SelectionFieldProp	: "Właściwości listy wyboru",
TextareaProp		: "Właściwości obszaru tekstowego",
FormProp			: "Właściwości formularza",

FontFormats			: "Normalny;Tekst sformatowany;Adres;Nagłówek 1;Nagłówek 2;Nagłówek 3;Nagłówek 4;Nagłówek 5;Nagłówek 6",

// Alerts and Messages
ProcessingXHTML		: "Przetwarzanie XHTML. Proszę czekać...",
Done				: "Gotowe",
PasteWordConfirm	: "Tekst, który chcesz wkleić, prawdopodobnie pochodzi z programu Word. Czy chcesz go wyczyścic przed wklejeniem?",
NotCompatiblePaste	: "Ta funkcja jest dostępna w programie Internet Explorer w wersji 5.5 lub wyższej. Czy chcesz wkleić tekst bez czyszczenia?",
UnknownToolbarItem	: "Nieznany element paska narzędzi \"%1\"",
UnknownCommand		: "Nieznana komenda \"%1\"",
NotImplemented		: "Komenda niezaimplementowana",
UnknownToolbarSet	: "Pasek narzędzi \"%1\" nie istnieje",
NoActiveX			: "Ustawienia zabezpieczeń twojej przeglądarki mogą ograniczyć niektóre funkcje edytora. Musisz włączyć opcję \"Uruchamianie formantów Activex i dodatków plugin\". W przeciwnym wypadku mogą pojawiać się błędy.",
BrowseServerBlocked : "Nie można otworzyć okno menadżera plików. Upewnij się, że wszystkie blokady wyskakujących okienek są wyłączone.",
DialogBlocked		: "Nie można otworzyć okna dialogowego. Upewnij się, że wszystkie blokady wyskakujących okienek są wyłączone.",
VisitLinkBlocked	: "It was not possible to open a new window. Make sure all popup blockers are disabled.",	//MISSING

// Dialogs
DlgBtnOK			: "OK",
DlgBtnCancel		: "Anuluj",
DlgBtnClose			: "Zamknij",
DlgBtnBrowseServer	: "Przeglądaj",
DlgAdvancedTag		: "Zaawansowane",
DlgOpOther			: "<Inny>",
DlgInfoTab			: "Informacje",
DlgAlertUrl			: "Proszę podać URL",

// General Dialogs Labels
DlgGenNotSet		: "<nie ustawione>",
DlgGenId			: "Id",
DlgGenLangDir		: "Kierunek tekstu",
DlgGenLangDirLtr	: "Od lewej do prawej (LTR)",
DlgGenLangDirRtl	: "Od prawej do lewej (RTL)",
DlgGenLangCode		: "Kod języka",
DlgGenAccessKey		: "Klawisz dostępu",
DlgGenName			: "Nazwa",
DlgGenTabIndex		: "Indeks tabeli",
DlgGenLongDescr		: "Długi opis hiperłącza",
DlgGenClass			: "Nazwa klasy CSS",
DlgGenTitle			: "Opis obiektu docelowego",
DlgGenContType		: "Typ MIME obiektu docelowego",
DlgGenLinkCharset	: "Kodowanie znaków obiektu docelowego",
DlgGenStyle			: "Styl",

// Image Dialog
DlgImgTitle			: "Właściwości obrazka",
DlgImgInfoTab		: "Informacje o obrazku",
DlgImgBtnUpload		: "Wyślij",
DlgImgURL			: "Adres URL",
DlgImgUpload		: "Wyślij",
DlgImgAlt			: "Tekst zastępczy",
DlgImgWidth			: "Szerokość",
DlgImgHeight		: "Wysokość",
DlgImgLockRatio		: "Zablokuj proporcje",
DlgBtnResetSize		: "Przywróć rozmiar",
DlgImgBorder		: "Ramka",
DlgImgHSpace		: "Odstęp poziomy",
DlgImgVSpace		: "Odstęp pionowy",
DlgImgAlign			: "Wyrównaj",
DlgImgAlignLeft		: "Do lewej",
DlgImgAlignAbsBottom: "Do dołu",
DlgImgAlignAbsMiddle: "Do środka w pionie",
DlgImgAlignBaseline	: "Do linii bazowej",
DlgImgAlignBottom	: "Do dołu",
DlgImgAlignMiddle	: "Do środka",
DlgImgAlignRight	: "Do prawej",
DlgImgAlignTextTop	: "Do góry tekstu",
DlgImgAlignTop		: "Do góry",
DlgImgPreview		: "Podgląd",
DlgImgAlertUrl		: "Podaj adres obrazka.",
DlgImgLinkTab		: "Hiperłącze",

// Flash Dialog
DlgFlashTitle		: "Właściwości elementu Flash",
DlgFlashChkPlay		: "Auto Odtwarzanie",
DlgFlashChkLoop		: "Pętla",
DlgFlashChkMenu		: "Włącz menu",
DlgFlashScale		: "Skaluj",
DlgFlashScaleAll	: "Pokaż wszystko",
DlgFlashScaleNoBorder	: "Bez Ramki",
DlgFlashScaleFit	: "Dokładne dopasowanie",

// Link Dialog
DlgLnkWindowTitle	: "Hiperłącze",
DlgLnkInfoTab		: "Informacje ",
DlgLnkTargetTab		: "Cel",

DlgLnkType			: "Typ hiperłącza",
DlgLnkTypeURL		: "Adres URL",
DlgLnkTypeAnchor	: "Odnośnik wewnątrz strony",
DlgLnkTypeEMail		: "Adres e-mail",
DlgLnkProto			: "Protokół",
DlgLnkProtoOther	: "<inny>",
DlgLnkURL			: "Adres URL",
DlgLnkAnchorSel		: "Wybierz etykietę",
DlgLnkAnchorByName	: "Wg etykiety",
DlgLnkAnchorById	: "Wg identyfikatora elementu",
DlgLnkNoAnchors		: "(W dokumencie nie zdefiniowano żadnych etykiet)",
DlgLnkEMail			: "Adres e-mail",
DlgLnkEMailSubject	: "Temat",
DlgLnkEMailBody		: "Treść",
DlgLnkUpload		: "Wyślij",
DlgLnkBtnUpload		: "Wyślij",

DlgLnkTarget		: "Cel",
DlgLnkTargetFrame	: "<ramka>",
DlgLnkTargetPopup	: "<wyskakujące okno>",
DlgLnkTargetBlank	: "Nowe okno (_blank)",
DlgLnkTargetParent	: "Okno nadrzędne (_parent)",
DlgLnkTargetSelf	: "To samo okno (_self)",
DlgLnkTargetTop		: "Okno najwyższe w hierarchii (_top)",
DlgLnkTargetFrameName	: "Nazwa Ramki Docelowej",
DlgLnkPopWinName	: "Nazwa wyskakującego okna",
DlgLnkPopWinFeat	: "Właściwości wyskakującego okna",
DlgLnkPopResize		: "Możliwa zmiana rozmiaru",
DlgLnkPopLocation	: "Pasek adresu",
DlgLnkPopMenu		: "Pasek menu",
DlgLnkPopScroll		: "Paski przewijania",
DlgLnkPopStatus		: "Pasek statusu",
DlgLnkPopToolbar	: "Pasek narzędzi",
DlgLnkPopFullScrn	: "Pełny ekran (IE)",
DlgLnkPopDependent	: "Okno zależne (Netscape)",
DlgLnkPopWidth		: "Szerokość",
DlgLnkPopHeight		: "Wysokość",
DlgLnkPopLeft		: "Pozycja w poziomie",
DlgLnkPopTop		: "Pozycja w pionie",

DlnLnkMsgNoUrl		: "Podaj adres URL",
DlnLnkMsgNoEMail	: "Podaj adres e-mail",
DlnLnkMsgNoAnchor	: "Wybierz etykietę",
DlnLnkMsgInvPopName	: "Nazwa wyskakującego okienka musi zaczynać się od znaku alfanumerycznego i nie może zawierać spacji",

// Color Dialog
DlgColorTitle		: "Wybierz kolor",
DlgColorBtnClear	: "Wyczyść",
DlgColorHighlight	: "Podgląd",
DlgColorSelected	: "Wybrane",

// Smiley Dialog
DlgSmileyTitle		: "Wstaw emotikonę",

// Special Character Dialog
DlgSpecialCharTitle	: "Wybierz znak specjalny",

// Table Dialog
DlgTableTitle		: "Właściwości tabeli",
DlgTableRows		: "Liczba wierszy",
DlgTableColumns		: "Liczba kolumn",
DlgTableBorder		: "Grubość ramki",
DlgTableAlign		: "Wyrównanie",
DlgTableAlignNotSet	: "<brak ustawień>",
DlgTableAlignLeft	: "Do lewej",
DlgTableAlignCenter	: "Do środka",
DlgTableAlignRight	: "Do prawej",
DlgTableWidth		: "Szerokość",
DlgTableWidthPx		: "piksele",
DlgTableWidthPc		: "%",
DlgTableHeight		: "Wysokość",
DlgTableCellSpace	: "Odstęp pomiędzy komórkami",
DlgTableCellPad		: "Margines wewnętrzny komórek",
DlgTableCaption		: "Tytuł",
DlgTableSummary		: "Podsumowanie",

// Table Cell Dialog
DlgCellTitle		: "Właściwości komórki",
DlgCellWidth		: "Szerokość",
DlgCellWidthPx		: "piksele",
DlgCellWidthPc		: "%",
DlgCellHeight		: "Wysokość",
DlgCellWordWrap		: "Zawijanie tekstu",
DlgCellWordWrapNotSet	: "<brak ustawień>",
DlgCellWordWrapYes	: "Tak",
DlgCellWordWrapNo	: "Nie",
DlgCellHorAlign		: "Wyrównanie poziome",
DlgCellHorAlignNotSet	: "<brak ustawień>",
DlgCellHorAlignLeft	: "Do lewej",
DlgCellHorAlignCenter	: "Do środka",
DlgCellHorAlignRight: "Do prawej",
DlgCellVerAlign		: "Wyrównanie pionowe",
DlgCellVerAlignNotSet	: "<brak ustawień>",
DlgCellVerAlignTop	: "Do góry",
DlgCellVerAlignMiddle	: "Do środka",
DlgCellVerAlignBottom	: "Do dołu",
DlgCellVerAlignBaseline	: "Do linii bazowej",
DlgCellRowSpan		: "Zajętość wierszy",
DlgCellCollSpan		: "Zajętość kolumn",
DlgCellBackColor	: "Kolor tła",
DlgCellBorderColor	: "Kolor ramki",
DlgCellBtnSelect	: "Wybierz...",

// Find and Replace Dialog
DlgFindAndReplaceTitle	: "Znajdź i zamień",

// Find Dialog
DlgFindTitle		: "Znajdź",
DlgFindFindBtn		: "Znajdź",
DlgFindNotFoundMsg	: "Nie znaleziono szukanego hasła.",

// Replace Dialog
DlgReplaceTitle			: "Zamień",
DlgReplaceFindLbl		: "Znajdź:",
DlgReplaceReplaceLbl	: "Zastąp przez:",
DlgReplaceCaseChk		: "Uwzględnij wielkość liter",
DlgReplaceReplaceBtn	: "Zastąp",
DlgReplaceReplAllBtn	: "Zastąp wszystko",
DlgReplaceWordChk		: "Całe słowa",

// Paste Operations / Dialog
PasteErrorCut	: "Ustawienia bezpieczeństwa Twojej przeglądarki nie pozwalają na automatyczne wycinanie tekstu. Użyj skrótu klawiszowego Ctrl+X.",
PasteErrorCopy	: "Ustawienia bezpieczeństwa Twojej przeglądarki nie pozwalają na automatyczne kopiowanie tekstu. Użyj skrótu klawiszowego Ctrl+C.",

PasteAsText		: "Wklej jako czysty tekst",
PasteFromWord	: "Wklej z Worda",

DlgPasteMsg2	: "Proszę wkleić w poniższym polu używając klawiaturowego skrótu (<STRONG>Ctrl+V</STRONG>) i kliknąć <STRONG>OK</STRONG>.",
DlgPasteSec		: "Zabezpieczenia przeglądarki uniemożliwiają wklejenie danych bezpośrednio do edytora. Proszę dane wkleić ponownie w tym okienku.",
DlgPasteIgnoreFont		: "Ignoruj definicje 'Font Face'",
DlgPasteRemoveStyles	: "Usuń definicje Stylów",

// Color Picker
ColorAutomatic	: "Automatycznie",
ColorMoreColors	: "Więcej kolorów...",

// Document Properties
DocProps		: "Właściwości dokumentu",

// Anchor Dialog
DlgAnchorTitle		: "Właściwości kotwicy",
DlgAnchorName		: "Nazwa kotwicy",
DlgAnchorErrorName	: "Wpisz nazwę kotwicy",

// Speller Pages Dialog
DlgSpellNotInDic		: "Słowa nie ma w słowniku",
DlgSpellChangeTo		: "Zmień na",
DlgSpellBtnIgnore		: "Ignoruj",
DlgSpellBtnIgnoreAll	: "Ignoruj wszystkie",
DlgSpellBtnReplace		: "Zmień",
DlgSpellBtnReplaceAll	: "Zmień wszystkie",
DlgSpellBtnUndo			: "Cofnij",
DlgSpellNoSuggestions	: "- Brak sugestii -",
DlgSpellProgress		: "Trwa sprawdzanie ...",
DlgSpellNoMispell		: "Sprawdzanie zakończone: nie znaleziono błędów",
DlgSpellNoChanges		: "Sprawdzanie zakończone: nie zmieniono żadnego słowa",
DlgSpellOneChange		: "Sprawdzanie zakończone: zmieniono jedno słowo",
DlgSpellManyChanges		: "Sprawdzanie zakończone: zmieniono %l słów",

IeSpellDownload			: "Słownik nie jest zainstalowany. Chcesz go ściągnąć?",

// Button Dialog
DlgButtonText		: "Tekst (Wartość)",
DlgButtonType		: "Typ",
DlgButtonTypeBtn	: "Przycisk",
DlgButtonTypeSbm	: "Wyślij",
DlgButtonTypeRst	: "Wyzeruj",

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Nazwa",
DlgCheckboxValue	: "Wartość",
DlgCheckboxSelected	: "Zaznaczone",

// Form Dialog
DlgFormName		: "Nazwa",
DlgFormAction	: "Akcja",
DlgFormMethod	: "Metoda",

// Select Field Dialog
DlgSelectName		: "Nazwa",
DlgSelectValue		: "Wartość",
DlgSelectSize		: "Rozmiar",
DlgSelectLines		: "linii",
DlgSelectChkMulti	: "Wielokrotny wybór",
DlgSelectOpAvail	: "Dostępne opcje",
DlgSelectOpText		: "Tekst",
DlgSelectOpValue	: "Wartość",
DlgSelectBtnAdd		: "Dodaj",
DlgSelectBtnModify	: "Zmień",
DlgSelectBtnUp		: "Do góry",
DlgSelectBtnDown	: "Do dołu",
DlgSelectBtnSetValue : "Ustaw wartość zaznaczoną",
DlgSelectBtnDelete	: "Usuń",

// Textarea Dialog
DlgTextareaName	: "Nazwa",
DlgTextareaCols	: "Kolumnu",
DlgTextareaRows	: "Wiersze",

// Text Field Dialog
DlgTextName			: "Nazwa",
DlgTextValue		: "Wartość",
DlgTextCharWidth	: "Szerokość w znakach",
DlgTextMaxChars		: "Max. szerokość",
DlgTextType			: "Typ",
DlgTextTypeText		: "Tekst",
DlgTextTypePass		: "Hasło",

// Hidden Field Dialog
DlgHiddenName	: "Nazwa",
DlgHiddenValue	: "Wartość",

// Bulleted List Dialog
BulletedListProp	: "Właściwości listy punktowanej",
NumberedListProp	: "Właściwości listy numerowanej",
DlgLstStart			: "Początek",
DlgLstType			: "Typ",
DlgLstTypeCircle	: "Koło",
DlgLstTypeDisc		: "Dysk",
DlgLstTypeSquare	: "Kwadrat",
DlgLstTypeNumbers	: "Cyfry (1, 2, 3)",
DlgLstTypeLCase		: "Małe litery (a, b, c)",
DlgLstTypeUCase		: "Duże litery (A, B, C)",
DlgLstTypeSRoman	: "Numeracja rzymska (i, ii, iii)",
DlgLstTypeLRoman	: "Numeracja rzymska (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Ogólne",
DlgDocBackTab		: "Tło",
DlgDocColorsTab		: "Kolory i marginesy",
DlgDocMetaTab		: "Meta Dane",

DlgDocPageTitle		: "Tytuł strony",
DlgDocLangDir		: "Kierunek pisania",
DlgDocLangDirLTR	: "Od lewej do prawej (LTR)",
DlgDocLangDirRTL	: "Od prawej do lewej (RTL)",
DlgDocLangCode		: "Kod języka",
DlgDocCharSet		: "Kodowanie znaków",
DlgDocCharSetCE		: "Środkowoeuropejskie",
DlgDocCharSetCT		: "Chińskie tradycyjne (Big5)",
DlgDocCharSetCR		: "Cyrylica",
DlgDocCharSetGR		: "Greckie",
DlgDocCharSetJP		: "Japońskie",
DlgDocCharSetKR		: "Koreańskie",
DlgDocCharSetTR		: "Tureckie",
DlgDocCharSetUN		: "Unicode (UTF-8)",
DlgDocCharSetWE		: "Zachodnioeuropejskie",
DlgDocCharSetOther	: "Inne kodowanie znaków",

DlgDocDocType		: "Nagłówek typu dokumentu",
DlgDocDocTypeOther	: "Inny typ dokumentu",
DlgDocIncXHTML		: "Dołącz deklarację XHTML",
DlgDocBgColor		: "Kolor tła",
DlgDocBgImage		: "Obrazek tła",
DlgDocBgNoScroll	: "Tło nieruchome",
DlgDocCText			: "Tekst",
DlgDocCLink			: "Hiperłącze",
DlgDocCVisited		: "Odwiedzane hiperłącze",
DlgDocCActive		: "Aktywne hiperłącze",
DlgDocMargins		: "Marginesy strony",
DlgDocMaTop			: "Górny",
DlgDocMaLeft		: "Lewy",
DlgDocMaRight		: "Prawy",
DlgDocMaBottom		: "Dolny",
DlgDocMeIndex		: "Słowa kluczowe (oddzielone przecinkami)",
DlgDocMeDescr		: "Opis dokumentu",
DlgDocMeAuthor		: "Autor",
DlgDocMeCopy		: "Prawa autorskie",
DlgDocPreview		: "Podgląd",

// Templates Dialog
Templates			: "Sablony",
DlgTemplatesTitle	: "Szablony zawartości",
DlgTemplatesSelMsg	: "Wybierz szablon do otwarcia w edytorze<br>(obecna zawartość okna edytora zostanie utracona):",
DlgTemplatesLoading	: "Ładowanie listy szablonów. Proszę czekać...",
DlgTemplatesNoTpl	: "(Brak zdefiniowanych szablonów)",
DlgTemplatesReplace	: "Zastąp aktualną zawartość",

// About Dialog
DlgAboutAboutTab	: "O ...",
DlgAboutBrowserInfoTab	: "O przeglądarce",
DlgAboutLicenseTab	: "Licencja",
DlgAboutVersion		: "wersja",
DlgAboutInfo		: "Więcej informacji uzyskasz pod adresem",

// Div Dialog
DlgDivGeneralTab	: "General",	//MISSING
DlgDivAdvancedTab	: "Advanced",	//MISSING
DlgDivStyle		: "Style",	//MISSING
DlgDivInlineStyle	: "Inline Style"	//MISSING
};
